"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Deprecated = void 0;
const core_1 = require("@tsed/core");
const jsonEntityFn_1 = require("../common/jsonEntityFn");
/**
 * Add deprecated metadata on the decorated element.
 *
 * ## Examples
 *
 * ```typescript
 *
 * @Deprecated()
 * class MyCtrl {
 *   @Deprecated()
 *   @Get("/")
 *   method(){
 *   }
 * }
 * ```
 *
 * @param deprecated
 * @decorator
 * @swagger
 * @schema
 * @operation
 */
function Deprecated(deprecated = true) {
    return (0, jsonEntityFn_1.JsonEntityFn)((store, args) => {
        switch ((0, core_1.decoratorTypeOf)(args)) {
            case core_1.DecoratorTypes.METHOD:
                store.operation.deprecated(deprecated);
                break;
            case core_1.DecoratorTypes.CLASS:
                (0, core_1.decorateMethodsOf)(args[0], Deprecated(deprecated));
                break;
            case core_1.DecoratorTypes.PARAM:
                store.parameter.set("deprecated", deprecated);
                break;
            case core_1.DecoratorTypes.PROP:
                store.schema.set("deprecated", deprecated);
                break;
            default:
                throw new core_1.UnsupportedDecoratorType(Deprecated, args);
        }
    });
}
exports.Deprecated = Deprecated;
//# sourceMappingURL=deprecated.js.map