"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getProperties = exports.getPropertiesStores = void 0;
const alterIgnore_1 = require("../hooks/alterIgnore");
const getInheritedStores_1 = require("./getInheritedStores");
const getJsonEntityStore_1 = require("./getJsonEntityStore");
/**
 * Return the list of properties including properties from inherited classes
 * @param target
 * @ignore
 */
function getPropertiesStores(target) {
    const store = target.isStore ? target : (0, getJsonEntityStore_1.getJsonEntityStore)(target);
    if (!store.$properties) {
        const stores = (0, getInheritedStores_1.getInheritedStores)(store);
        store.$properties = new Map();
        stores.forEach((currentStore) => {
            currentStore.children.forEach((propStore) => {
                if (!store.$properties.has(propStore.propertyKey)) {
                    store.$properties.set(propStore.propertyKey, propStore);
                }
            });
        });
    }
    return store.$properties;
}
exports.getPropertiesStores = getPropertiesStores;
/**
 * @ignore
 */
function getProperties(target, options = {}) {
    const stores = getPropertiesStores(target);
    const map = new Map();
    stores.forEach((store, key) => {
        if (!options.withIgnoredProps) {
            if ((0, alterIgnore_1.alterIgnore)(store.itemSchema, options)) {
                return;
            }
        }
        map.set(key, store);
    });
    return map;
}
exports.getProperties = getProperties;
//# sourceMappingURL=getPropertiesStores.js.map